==> ejc-accplat-impl-3.0.0-20240119.024643-122-sources.jar: com/ejianc/business/accplat/config/bean/BillAuxiliarySetEntity.java <==
package com.ejianc.business.accplat.config.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 会计平台设置-辅助核算项关联
 * 
 * @author generator
 * 
 */
 @TableName("ejc_accplat_bill_auxiliary_set")
public class BillAuxiliarySetEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_type_id")
    private Long billTypeId; // 单据类型id
    @TableField(value="bill_type_code")
    private String billTypeCode; // 单据类型编码
    @TableField(value="bill_type_name")
    private String billTypeName; // 单据类型
    @TableField(value="auxiliary_id")
    private Long auxiliaryId; // 辅助核算项id
    @TableField(value="auxiliary_code")
    private String auxiliaryCode; // 辅助核算项编码
    @TableField(value="auxiliary_name")
    private String auxiliaryName; // 辅助核算项名称
    @TableField(value="refer_id")
    private Long referId; // 档案id
    @TableField(value="refer_code")
    private String referCode; // 档案参照编码
    @TableField(value="refer_name")
    private String referName; // 档案参照名称
    @TableField(value="data_type")
    private Integer dataType; // 数据类型1基础档案2自定义档案
    @TableField(value="column_view")
    private String columnView; // 字段显示
    @TableField(value="column_expression")
    private String columnExpression; // 字段表达式

    @TableField(value="column_id")
    private Long columnId; // 字段id

    @TableField(value="column_name")
    private String columnName; // 字段

    @TableField(value="column_pos")
    private String columnPos;  // 字段位置:H主表、HR主表关联、B子表、BR子表关联

    public String getColumnPos() {
        return columnPos;
    }

    public void setColumnPos(String columnPos) {
        this.columnPos = columnPos;
    }


    public Long getColumnId() {
        return columnId;
    }

    public void setColumnId(Long columnId) {
        this.columnId = columnId;
    }

    public String getColumnName() {
        return columnName;
    }

    public void setColumnName(String columnName) {
        this.columnName = columnName;
    }
    

    public Long getBillTypeId() {
        return billTypeId;
    }

    public void setBillTypeId(Long billTypeId) {
        this.billTypeId = billTypeId;
    }
    public String getBillTypeCode() {
        return billTypeCode;
    }

    public void setBillTypeCode(String billTypeCode) {
        this.billTypeCode = billTypeCode;
    }
    public String getBillTypeName() {
        return billTypeName;
    }

    public void setBillTypeName(String billTypeName) {
        this.billTypeName = billTypeName;
    }
    public Long getAuxiliaryId() {
        return auxiliaryId;
    }

    public void setAuxiliaryId(Long auxiliaryId) {
        this.auxiliaryId = auxiliaryId;
    }
    public String getAuxiliaryCode() {
        return auxiliaryCode;
    }

    public void setAuxiliaryCode(String auxiliaryCode) {
        this.auxiliaryCode = auxiliaryCode;
    }
    public String getAuxiliaryName() {
        return auxiliaryName;
    }

    public void setAuxiliaryName(String auxiliaryName) {
        this.auxiliaryName = auxiliaryName;
    }
    public Long getReferId() {
        return referId;
    }

    public void setReferId(Long referId) {
        this.referId = referId;
    }
    public String getReferCode() {
        return referCode;
    }

    public void setReferCode(String referCode) {
        this.referCode = referCode;
    }
    public String getReferName() {
        return referName;
    }

    public void setReferName(String referName) {
        this.referName = referName;
    }
    public Integer getDataType() {
        return dataType;
    }

    public void setDataType(Integer dataType) {
        this.dataType = dataType;
    }
    public String getColumnView() {
        return columnView;
    }

    public void setColumnView(String columnView) {
        this.columnView = columnView;
    }
    public String getColumnExpression() {
        return columnExpression;
    }

    public void setColumnExpression(String columnExpression) {
        this.columnExpression = columnExpression;
    }
    
}

==> ejc-accplat-impl-3.0.0-20240513.060048-183-sources.jar: com/ejianc/business/accplat/config/bean/BillAuxiliarySetEntity.java <==
package com.ejianc.business.accplat.config.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 会计平台设置-辅助核算项关联
 * 
 * @author generator
 * 
 */
 @TableName("ejc_accplat_bill_auxiliary_set")
public class BillAuxiliarySetEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_type_id")
    private Long billTypeId; // 单据类型id
    @TableField(value="bill_type_code")
    private String billTypeCode; // 单据类型编码
    @TableField(value="bill_type_name")
    private String billTypeName; // 单据类型
    @TableField(value="auxiliary_id")
    private Long auxiliaryId; // 辅助核算项id
    @TableField(value="auxiliary_code")
    private String auxiliaryCode; // 辅助核算项编码
    @TableField(value="auxiliary_name")
    private String auxiliaryName; // 辅助核算项名称
    @TableField(value="refer_id")
    private Long referId; // 档案id
    @TableField(value="refer_code")
    private String referCode; // 档案参照编码
    @TableField(value="refer_name")
    private String referName; // 档案参照名称
    @TableField(value="data_type")
    private Integer dataType; // 数据类型1基础档案2自定义档案
    @TableField(value="column_view")
    private String columnView; // 字段显示
    @TableField(value="column_expression")
    private String columnExpression; // 字段表达式

    @TableField(value="column_id")
    private Long columnId; // 字段id

    @TableField(value="column_name")
    private String columnName; // 字段

    @TableField(value="column_pos")
    private String columnPos;  // 字段位置:H主表、HR主表关联、B子表、BR子表关联

    @TableField(value="memo")
    private String memo; // 备注

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getColumnPos() {
        return columnPos;
    }

    public void setColumnPos(String columnPos) {
        this.columnPos = columnPos;
    }


    public Long getColumnId() {
        return columnId;
    }

    public void setColumnId(Long columnId) {
        this.columnId = columnId;
    }

    public String getColumnName() {
        return columnName;
    }

    public void setColumnName(String columnName) {
        this.columnName = columnName;
    }
    

    public Long getBillTypeId() {
        return billTypeId;
    }

    public void setBillTypeId(Long billTypeId) {
        this.billTypeId = billTypeId;
    }
    public String getBillTypeCode() {
        return billTypeCode;
    }

    public void setBillTypeCode(String billTypeCode) {
        this.billTypeCode = billTypeCode;
    }
    public String getBillTypeName() {
        return billTypeName;
    }

    public void setBillTypeName(String billTypeName) {
        this.billTypeName = billTypeName;
    }
    public Long getAuxiliaryId() {
        return auxiliaryId;
    }

    public void setAuxiliaryId(Long auxiliaryId) {
        this.auxiliaryId = auxiliaryId;
    }
    public String getAuxiliaryCode() {
        return auxiliaryCode;
    }

    public void setAuxiliaryCode(String auxiliaryCode) {
        this.auxiliaryCode = auxiliaryCode;
    }
    public String getAuxiliaryName() {
        return auxiliaryName;
    }

    public void setAuxiliaryName(String auxiliaryName) {
        this.auxiliaryName = auxiliaryName;
    }
    public Long getReferId() {
        return referId;
    }

    public void setReferId(Long referId) {
        this.referId = referId;
    }
    public String getReferCode() {
        return referCode;
    }

    public void setReferCode(String referCode) {
        this.referCode = referCode;
    }
    public String getReferName() {
        return referName;
    }

    public void setReferName(String referName) {
        this.referName = referName;
    }
    public Integer getDataType() {
        return dataType;
    }

    public void setDataType(Integer dataType) {
        this.dataType = dataType;
    }
    public String getColumnView() {
        return columnView;
    }

    public void setColumnView(String columnView) {
        this.columnView = columnView;
    }
    public String getColumnExpression() {
        return columnExpression;
    }

    public void setColumnExpression(String columnExpression) {
        this.columnExpression = columnExpression;
    }
    
}
